@@ -62,7 +62,7 @@ class Select(BaseArgsParsing, metaclass=abc.ABCMeta):
                         orm_q.add(~Q(**{real_key: data.get(key)}), Q.AND)
                     elif keyword == self.ISNULL:
                         value = self.conver_bool(data.get(key))
-                        orm_q.add(~Q(**{real_key: value}), Q.AND)
+                        orm_q.add(Q(**{key: value}), Q.AND)
                     elif keyword == self.OR:
                         if "|" in values:
                             real_values = values.split("|")
