@@ -115,6 +115,8 @@ class BaseView(APIView, Select, BaseORM):
         try:
             data, pk, value_pk, conditions = self.parsing_args_and_data(request, results, data, extend_conditions, pk)
             if results.code != 200:
+                if need_queryset:
+                    return results, None
                 if need_results:
                     return results
                 return RESTResponse(results)
